@@ -56,6 +56,7 @@ import java.security.MessageDigest;
 import java.security.NoSuchAlgorithmException;
 import java.util.Arrays;
 import java.util.HashSet;
+import java.util.List;
 import java.util.Vector;
 import java.util.Map;
 //}}}
@@ -84,7 +85,7 @@ import java.util.Map;
  * </ul>
  *
  * @author Slava Pestov
- * @version $Id: Buffer.java 16444 2009-11-05 12:50:10Z shlomy $
+ * @version $Id: Buffer.java 17764 2010-05-08 09:46:42Z k_satoda $
  */
 public class Buffer extends JEditBuffer
 {
@@ -869,7 +870,7 @@ public class Buffer extends JEditBuffer
 			d = false;
 		if (d && getLength() == initialLength)
 		{
-			if (jEdit.getBooleanProperty("useMD5forDirtyCalculation")) 
+			if (jEdit.getBooleanProperty("useMD5forDirtyCalculation"))
 				d = !Arrays.equals(calculateHash(), md5hash);
 		}
 		super.setDirty(d);
@@ -988,7 +989,8 @@ public class Buffer extends JEditBuffer
 		super.propertiesChanged();
 		setAutoReloadDialog(jEdit.getBooleanProperty("autoReloadDialog"));
 		setAutoReload(jEdit.getBooleanProperty("autoReload"));
-		EditBus.send(new BufferUpdate(this,null,BufferUpdate.PROPERTIES_CHANGED));
+		if (!isTemporary())
+			EditBus.send(new BufferUpdate(this,null,BufferUpdate.PROPERTIES_CHANGED));
 	} //}}}
 
 	//{{{ getDefaultProperty() method
@@ -1591,6 +1593,28 @@ public class Buffer extends JEditBuffer
 		return name + " (" + MiscUtilities.abbreviate(directory) + ')';
 	} //}}}
 
+	//{{{ addBufferUndoListener() method
+	/**
+	 * Adds a buffer undo listener.
+	 * @param listener The listener
+	 * @since jEdit 4.3pre18
+	 */
+	public void addBufferUndoListener(BufferUndoListener listener)
+	{
+		undoListeners.add(listener);
+	} //}}}
+
+	//{{{ removeBufferUndoListener() method
+	/**
+	 * Removes a buffer undo listener.
+	 * @param listener The listener
+	 * @since jEdit 4.3pre18
+	 */
+	public void removeBufferUndoListener(BufferUndoListener listener)
+	{
+		undoListeners.remove(listener);
+	} //}}}
+
 	//}}}
 
 	//{{{ Package-private members
@@ -1630,6 +1654,8 @@ public class Buffer extends JEditBuffer
 		setFlag(NEW_FILE,newFile);
 		setFlag(AUTORELOAD,jEdit.getBooleanProperty("autoReload"));
 		setFlag(AUTORELOAD_DIALOG,jEdit.getBooleanProperty("autoReloadDialog"));
+
+		undoListeners = new Vector<BufferUndoListener>();
 	} //}}}
 
 	//{{{ commitTemporary() method
@@ -1668,6 +1694,77 @@ public class Buffer extends JEditBuffer
 
 	//}}}
 
+	//{{{ Protected members
+
+	//{{{ fireBeginUndo() method
+	protected void fireBeginUndo()
+	{
+		for (BufferUndoListener listener: undoListeners)
+		{
+			try
+			{
+				listener.beginUndo(this);
+			}
+			catch(Throwable t)
+			{
+				Log.log(Log.ERROR,this,"Exception while sending buffer undo event to "+ listener +" :");
+				Log.log(Log.ERROR,this,t);
+			}
+		}
+	} //}}}
+
+	//{{{ fireEndUndo() method
+	protected void fireEndUndo()
+	{
+		for (BufferUndoListener listener: undoListeners)
+		{
+			try
+			{
+				listener.endUndo(this);
+			}
+			catch(Throwable t)
+			{
+				Log.log(Log.ERROR,this,"Exception while sending buffer undo event to "+ listener +" :");
+				Log.log(Log.ERROR,this,t);
+			}
+		}
+	} //}}}
+
+	//{{{ fireBeginRedo() method
+	protected void fireBeginRedo()
+	{
+		for (BufferUndoListener listener: undoListeners)
+		{
+			try
+			{
+				listener.beginRedo(this);
+			}
+			catch(Throwable t)
+			{
+				Log.log(Log.ERROR,this,"Exception while sending buffer begin redo event to "+ listener +" :");
+				Log.log(Log.ERROR,this,t);
+			}
+		}
+	} //}}}
+	
+	//{{{ fireEndRedo() method
+	protected void fireEndRedo()
+	{
+		for (BufferUndoListener listener: undoListeners)
+		{
+			try
+			{
+				listener.endRedo(this);
+			}
+			catch(Throwable t)
+			{
+				Log.log(Log.ERROR,this,"Exception while sending buffer end redo event to "+ listener +" :");
+				Log.log(Log.ERROR,this,t);
+			}
+		}
+	} //}}}
+	//}}}
+
 	//{{{ Private members
 
 	//{{{ Flags
@@ -1717,6 +1814,7 @@ public class Buffer extends JEditBuffer
 	private final Vector<Marker> markers;
 
 	private Socket waitSocket;
+	private List<BufferUndoListener> undoListeners;
 	//}}}
 
 	//{{{ setPath() method
@@ -1901,12 +1999,12 @@ public class Buffer extends JEditBuffer
 	/** @return an MD5 hash of the contents of the buffer */
 	private byte[] calculateHash()
 	{
-		final byte[] dummy = new byte[1]; 
+		final byte[] dummy = new byte[1];
 		if (!jEdit.getBooleanProperty("useMD5forDirtyCalculation"))
 			return dummy;
 		ByteBuffer bb = null;
 		readLock();
-		try 
+		try
 		{
 			// Log.log(Log.NOTICE, this, "calculateHash()");
 			int length = getLength();
@@ -1914,38 +2012,38 @@ public class Buffer extends JEditBuffer
 			CharBuffer cb = bb.asCharBuffer();
 			cb.append( getSegment(0, length) );
 		}
-		finally 
+		finally
 		{
 			readUnlock();
-		} 
-		try 
+		}
+		try
 		{
 			MessageDigest digest = java.security.MessageDigest.getInstance("MD5");
 			digest.update( bb );
 			return digest.digest();
 		}
-		catch (NoSuchAlgorithmException nsae) 
+		catch (NoSuchAlgorithmException nsae)
 		{
 			Log.log(Log.ERROR, this, "Can't Calculate MD5 hash!", nsae);
 			return dummy;
 		}
-		
+
 	}
-	
+
 	/** Update the buffer's members with the current hash and length,
 	 *  for later comparison.
 	 */
-	private void updateHash() 
+	private void updateHash()
 	{
 		initialLength = getLength();
 		md5hash = calculateHash();
 	}
-	
+
 	//{{{ finishLoading() method
 	private void finishLoading()
 	{
 		updateHash();
-			
+
 		parseBufferLocalProperties();
 		// AHA!
 		// this is probably the only way to fix this
@@ -1981,7 +2079,7 @@ public class Buffer extends JEditBuffer
 		String oldSymlinkPath, String path,
 		boolean rename, boolean error)
 	{
-		
+
 		//{{{ Set the buffer's path
 		// Caveat: won't work if save() called with a relative path.
 		// But I don't think anyone calls it like that anyway.
@@ -2095,7 +2193,7 @@ public class Buffer extends JEditBuffer
 				}
 
 				updateHash();
-				
+
 				if (!isTemporary())
 				{
 					EditBus.send(new BufferUpdate(this,
