@@ -209,6 +209,24 @@ public class HelpTOCPanel extends JPanel
 				new URL(helpViewer.getBaseURL()
 					+ '/' + path).openStream(), h);
 		}
+		catch(FileNotFoundException e)
+		{
+			/* it is acceptable only for the API TOC :
+			   the user can choose not to install them
+			 */
+			if("api/toc.xml".equals(path))
+			{
+				Log.log(Log.NOTICE,this,
+					"The API docs for jEdit will not be available (reinstall jEdit if you want them)");
+				root.add(
+					createNode("http://www.jedit.org/api/overview-summary.html",
+						jEdit.getProperty("helpviewer.toc.online-apidocs")));
+			}
+			else
+			{
+				Log.log(Log.ERROR,this,e);
+			}
+		}
 		catch(IOException e)
 		{
 			Log.log(Log.ERROR,this,e);
